@@ -1,3 +1,4 @@
+import copy
 import functools
 import itertools
 import multiprocessing
@@ -7,7 +8,7 @@ import shutil
 import subprocess
 import sys
 import time
-import warnings
+from logging import getLogger
 from pathlib import Path
 
 import numpy as np
@@ -18,6 +19,8 @@ from rec_to_binaries.binary_utils import (TrodesDIOBinaryLoader,
                                           TrodesSpikeBinaryLoader,
                                           TrodesTimestampBinaryLoader)
 
+logger = getLogger(__name__)
+
 
 class TrodesDataFormatWarning(RuntimeWarning):
     pass
@@ -215,7 +218,7 @@ class TrodesPosExtractedFileNameParser(TrodesRawFileNameParser):
 class TrodesAnimalInfo:
 
     def __init__(self, base_dir, anim_name, RawFileParser=TrodesRawFileNameParser,
-                 out_dir=None, dates=None):
+                 out_dir=None, dates=None, trodes_version=None):
         self.RawFileNameParser = RawFileParser
         self.base_dir = base_dir
         self.anim_name = anim_name
@@ -247,13 +250,16 @@ class TrodesAnimalInfo:
             self.raw_rec_files[date] = {}
             day_rec_filenames = self._get_rec_paths(
                 day_path, self.RawFileNameParser)
-            self.trodes_version = self._get_trodes_version(day_path)
+            if trodes_version is None:
+                self.trodes_version = self._get_trodes_version(day_path)
+            else:
+                self.trodes_version = trodes_version
             for rec_filename_parsed, rec_path in day_rec_filenames:
                 if rec_filename_parsed.date != date:
-                    warnings.warn(('For rec file ({}) the date field does not match '
-                                   'the folder date ({}). This should be fixed or could have'
-                                   'unintended parsing consequences.').
-                                  format(rec_filename_parsed.filename, date), TrodesDataFormatWarning)
+                    logger.warn(('For rec file ({}) the date field does not match '
+                                 'the folder date ({}). This should be fixed or could have'
+                                 'unintended parsing consequences.').
+                                format(rec_filename_parsed.filename, date), TrodesDataFormatWarning)
                 self.raw_rec_files[date][rec_filename_parsed.epochtuple] = (
                     rec_filename_parsed, rec_path)
 
@@ -408,9 +414,11 @@ class TrodesAnimalInfo:
                                        .append(pd.DataFrame(directory_path_fields,
                                                             columns=partial_extracted_columns),
                                                ignore_index=True))
-        datatype_paths_df = (directory_entries_df.drop('directory', 1).merge(right=partial_extracted_paths,
-                                                                             left_index=True,
-                                                                             right_on='dir_index')
+        datatype_paths_df = (directory_entries_df
+                             .drop(labels='directory', axis=1)
+                             .merge(right=partial_extracted_paths,
+                                    left_index=True,
+                                    right_on='dir_index')
                              .sort_values(sort_on_fields)
                              .reset_index(drop=True))
 
@@ -559,8 +567,8 @@ class TrodesAnimalInfo:
                                                                            date_path_entry.path])),
                                                                  ignore_index=True)
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid folder name in preprocessing folder date ({}) folder ({}), ignoring.'.
-                                       format(date, date_path_entry.name)))
+                        logger.warn(('Invalid folder name in preprocessing folder date ({}) folder ({}), ignoring.'.
+                                     format(date, date_path_entry.name)))
         # sort and reindex paths
         full_data_paths = full_data_paths.sort_values(
             ['date', 'epoch', 'label_ext', 'datatype']).reset_index(drop=True)
@@ -577,10 +585,10 @@ class TrodesAnimalInfo:
                     filename_parser = ExtractedFileParser(dir_entry.name)
                     file_list.append((filename_parser, dir_entry.path))
                 except TrodesDataFormatError:
-                    warnings.warn('File ({}) does not match file parser ({}). Skipping.'.
-                                  format(dir_entry.path,
-                                         ExtractedFileParser.__name__),
-                                  TrodesDataFormatWarning)
+                    logger.warn('File ({}) does not match file parser ({}). Skipping.'.
+                                format(dir_entry.path,
+                                       ExtractedFileParser.__name__),
+                                TrodesDataFormatWarning)
         return file_list
 
     @staticmethod
@@ -610,11 +618,11 @@ class TrodesAnimalInfo:
                         TrodesAnimalInfo._expand_str_date(anim_dir_entry.name)
                         anim_day_paths[anim_dir_entry.name] = anim_dir_entry.path
                     except ValueError:
-                        warnings.warn(('animal path ({}) contains a data directory ({}) '
-                                       'that does not conform to date format %Y%m%d.').
-                                      format(anim_path, anim_dir_entry.name), TrodesDataFormatWarning)
+                        logger.warn(('animal path ({}) contains a data directory ({}) '
+                                     'that does not conform to date format %Y%m%d.').
+                                    format(anim_path, anim_dir_entry.name), TrodesDataFormatWarning)
         except FileNotFoundError:
-            warnings.warn(('anim path ({}) does not exist.'.format(
+            logger.warn(('anim path ({}) does not exist.'.format(
                 anim_path)), TrodesDataFormatWarning)
         return anim_day_paths
 
@@ -634,9 +642,9 @@ class TrodesAnimalInfo:
                         anim_rec_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes rec filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes rec filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return anim_rec_paths
 
@@ -661,9 +669,9 @@ class TrodesAnimalInfo:
                         anim_pos_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes videoPositionTracking filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes videoPositionTracking filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return anim_pos_paths
 
@@ -682,9 +690,9 @@ class TrodesAnimalInfo:
                         anim_h264_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes h264 filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes h264 filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return anim_h264_paths
 
@@ -703,9 +711,9 @@ class TrodesAnimalInfo:
                         anim_video_times_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes videoTimeStamps filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes videoTimeStamps filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return anim_video_times_paths
 
@@ -724,9 +732,9 @@ class TrodesAnimalInfo:
                         anim_video_hwframecount_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes videoTimeStamps.cameraHWFrameCount filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes videoTimeStamps.cameraHWFrameCount filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return anim_video_hwframecount_paths
 
@@ -745,9 +753,9 @@ class TrodesAnimalInfo:
                         trodes_comment_paths.append(
                             (trodes_filename_parsed, dir_entry.path))
                     except TrodesDataFormatError:
-                        warnings.warn(('Invalid trodes .trodesComments filename ({}), '
-                                       'cannot be parsed, skipping.').
-                                      format(dir_entry.path), TrodesDataFormatWarning)
+                        logger.warn(('Invalid trodes .trodesComments filename ({}), '
+                                     'cannot be parsed, skipping.').
+                                    format(dir_entry.path), TrodesDataFormatWarning)
 
         return trodes_comment_paths
 
@@ -786,10 +794,10 @@ class TrodesPreprocessingLFPEpoch:
                 self.lfp = pd.concat([self.lfp, pd.DataFrame(lfp_bin.data, columns=single_col)], axis=1,
                                      verify_integrity=True)
             else:
-                warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                               'has a bad preprocessing path entry, ntrode or '
-                               'channel has a nan entry that is not a timestamp '
-                               'file, skipping.').format(anim.anim_name, date, epochtuple))
+                logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                             'has a bad preprocessing path entry, ntrode or '
+                             'channel has a nan entry that is not a timestamp '
+                             'file, skipping.').format(anim.anim_name, date, epochtuple))
 
         # get default timestamp
         try:
@@ -797,9 +805,9 @@ class TrodesPreprocessingLFPEpoch:
                 self.LFP_timestamp_paths['time_label'] == '']
             orig_timestamp_path = orig_timestamp_path_entries['path'].values[0]
             if len(orig_timestamp_path_entries) > 1:
-                warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                               'has multiple original timestamp path entries, '
-                               'using ({}).').format(anim.anim_name, date, epochtuple, orig_timestamp_path))
+                logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                             'has multiple original timestamp path entries, '
+                             'using ({}).').format(anim.anim_name, date, epochtuple, orig_timestamp_path))
             orig_timestamp_bin = TrodesTimestampBinaryLoader(
                 orig_timestamp_path)
             self.orig_timestamps = orig_timestamp_bin.data
@@ -813,16 +821,16 @@ class TrodesPreprocessingLFPEpoch:
                 self.LFP_timestamp_paths['time_label'] == 'adj']
             adj_timestamp_path = adj_timestamp_path_entries['path'].values[0]
             if len(adj_timestamp_path_entries) > 1:
-                warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                               'has multiple adjusted timestamp path entries, '
-                               'using ({}).').format(anim.anim_name, date, epochtuple, adj_timestamp_path))
+                logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                             'has multiple adjusted timestamp path entries, '
+                             'using ({}).').format(anim.anim_name, date, epochtuple, adj_timestamp_path))
             adj_timestamp_bin = TrodesTimestampBinaryLoader(adj_timestamp_path)
             self.adj_timestamps = adj_timestamp_bin.data
         except (IndexError, FileNotFoundError):
             self.adj_timestamps = None
-            warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                           'missing adjusted timestamps file.').format(anim.anim_name, date, epochtuple),
-                          TrodesDataFormatWarning)
+            logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                         'missing adjusted timestamps file.').format(anim.anim_name, date, epochtuple),
+                        TrodesDataFormatWarning)
 
         # always use original timestamp
         self.lfp.set_index(keys=self.orig_timestamps, inplace=True)
@@ -847,10 +855,10 @@ class TrodesPreprocessingSpikeEpoch:
                 path_list.append(path_tup.path)
                 ntrode_list.append(path_tup.ntrode)
             else:
-                warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                               'has a bad preprocessing path entry, ntrode '
-                               'has a nan entry that is not a timestamp '
-                               'file, skipping.').format(anim.anim_name, date, epochtuple))
+                logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                             'has a bad preprocessing path entry, ntrode '
+                             'has a nan entry that is not a timestamp '
+                             'file, skipping.').format(anim.anim_name, date, epochtuple))
 
         p = multiprocessing.Pool(parallel_instances)
         spikes_loaded = p.map(TrodesSpikeBinaryLoader, path_list, chunksize=1)
@@ -873,18 +881,18 @@ class TrodesPreprocessingPosEpoch:
         for path_tup in self.pos_paths.itertuples():
             if path_tup.timestamp_file:
                 if path_tup.time_label in self.timestamps:
-                    warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                                   'has multiple timestamps with same label, using first one.').
-                                  format(anim.anim_name, date, epochtuple))
+                    logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                                 'has multiple timestamps with same label, using first one.').
+                                format(anim.anim_name, date, epochtuple))
                     break
                 timestamp_bin = TrodesTimestampBinaryLoader(path_tup.path)
                 self.timestamps[path_tup.time_label] = timestamp_bin.data
             elif not pd.isnull(path_tup.pos_label):
                 # assume path is for a position file
                 if path_tup.pos_label in self.pos:
-                    warnings.warn(('Animal ({}), date ({}), epoch ({}) '
-                                   'has multiple pos data with same label, using first one.').
-                                  format(anim.anim_name, date, epochtuple))
+                    logger.warn(('Animal ({}), date ({}), epoch ({}) '
+                                 'has multiple pos data with same label, using first one.').
+                                format(anim.anim_name, date, epochtuple))
                     break
                 pos_bin = TrodesPosBinaryLoader(path_tup.path)
                 self.pos[path_tup.pos_label] = pos_bin.pos
@@ -1016,7 +1024,7 @@ class ExtractRawTrodesData:
         if trodes_version < 2:
             export_cmd = 'exportLFP'
         else:
-            export_cmd = 'trodesexport -lfp'
+            export_cmd = ['trodesexport', '-lfp']
 
         self._extract_rec_generic(export_cmd=export_cmd, export_dir_ext='LFP',
                                   dates=dates, epochs=epochs,
@@ -1141,10 +1149,10 @@ class ExtractRawTrodesData:
                     raise
                 else:
                     # exception should be converted to a warning
-                    warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                  .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                          sys.exc_info()[2].tb_lineno),
-                                  TrodesDataFormatWarning)
+                    logger.warn(repr(err) + ' (thrown from {}:{})'
+                                .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                        sys.exc_info()[2].tb_lineno),
+                                TrodesDataFormatWarning)
 
     def prepare_mountain_dir(self, dates, epochs, use_folder_date=False, stop_error=False):
 
@@ -1184,10 +1192,10 @@ class ExtractRawTrodesData:
                     raise
                 else:
                     # exception should be converted to a warning
-                    warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                  .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                          sys.exc_info()[2].tb_lineno),
-                                  TrodesDataFormatWarning)
+                    logger.warn(repr(err) + ' (thrown from {}:{})'
+                                .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                        sys.exc_info()[2].tb_lineno),
+                                TrodesDataFormatWarning)
 
     def prepare_pos_dir(self, dates, epochs, overwrite=False, use_folder_date=False, stop_error=False):
         for dir_date, epoch in itertools.product(dates, epochs):
@@ -1238,10 +1246,10 @@ class ExtractRawTrodesData:
 
                     except KeyError as err:
                         # this file does not exist
-                        warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                      .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                              sys.exc_info()[2].tb_lineno),
-                                      TrodesDataFormatWarning)
+                        logger.warn(repr(err) + ' (thrown from {}:{})'
+                                    .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                            sys.exc_info()[2].tb_lineno),
+                                    TrodesDataFormatWarning)
 
                     try:
                         (raw_postime_filename_parser, raw_postime_path) = \
@@ -1261,10 +1269,10 @@ class ExtractRawTrodesData:
 
                     except KeyError as err:
                         # this file does not exist
-                        warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                      .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                              sys.exc_info()[2].tb_lineno),
-                                      TrodesDataFormatWarning)
+                        logger.warn(repr(err) + ' (thrown from {}:{})'
+                                    .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                            sys.exc_info()[2].tb_lineno),
+                                    TrodesDataFormatWarning)
 
                     try:
                         (raw_poshwframecount_filename_parser, raw_poshwframecount_path) = \
@@ -1285,10 +1293,10 @@ class ExtractRawTrodesData:
 
                     except KeyError as err:
                         # this file does not exist
-                        warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                      .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                              sys.exc_info()[2].tb_lineno),
-                                      TrodesDataFormatWarning)
+                        logger.warn(repr(err) + ' (thrown from {}:{})'
+                                    .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                            sys.exc_info()[2].tb_lineno),
+                                    TrodesDataFormatWarning)
 
             except TrodesDataFormatError as err:
                 if stop_error:
@@ -1296,10 +1304,10 @@ class ExtractRawTrodesData:
                     raise
                 else:
                     # exception should be converted to a warning
-                    warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                  .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                          sys.exc_info()[2].tb_lineno),
-                                  TrodesDataFormatWarning)
+                    logger.warn(repr(err) + ' (thrown from {}:{})'
+                                .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                        sys.exc_info()[2].tb_lineno),
+                                TrodesDataFormatWarning)
 
     def _extract_rec_generic(self, export_cmd, export_dir_ext,
                              dates, epochs, export_args=(), overwrite=False, stop_error=False,
@@ -1324,6 +1332,14 @@ class ExtractRawTrodesData:
 
         next_cmd_id = 0
 
+        if isinstance(export_cmd, str):
+            export_cmd = [export_cmd]
+        # create log file for each run of the export command
+        if len(export_cmd) > 1:
+            cmd_type = export_cmd[1].replace('-', '')
+        else:
+            cmd_type = export_cmd[0]
+
         file_paths_parsed = set()
         for dir_date, epoch in itertools.product(dates, epochs):
             try:
@@ -1349,15 +1365,15 @@ class ExtractRawTrodesData:
 
                     if file_parser.date != dir_date:
                         if use_folder_date:
-                            warnings.warn(('For rec file ({}) the date field does not match '
-                                           'the folder date ({}). Forcing file to use folder date').
-                                          format(file_parser.filename, dir_date), TrodesDataFormatWarning)
+                            logger.warn(('For rec file ({}) the date field does not match '
+                                         'the folder date ({}). Forcing file to use folder date').
+                                        format(file_parser.filename, dir_date), TrodesDataFormatWarning)
                         else:
-                            warnings.warn(('For rec file ({}) the date field does not match '
-                                           'the folder date ({}). This should be fixed or could have '
-                                           'unintended parsing consequences. Will proceed by maintaining '
-                                           'folder date and using rec file date in extracted files.').
-                                          format(file_parser.filename, dir_date), TrodesDataFormatWarning)
+                            logger.warn(('For rec file ({}) the date field does not match '
+                                         'the folder date ({}). This should be fixed or could have '
+                                         'unintended parsing consequences. Will proceed by maintaining '
+                                         'folder date and using rec file date in extracted files.').
+                                        format(file_parser.filename, dir_date), TrodesDataFormatWarning)
 
                     if use_folder_date:
                         out_base_date = dir_date
@@ -1392,10 +1408,10 @@ class ExtractRawTrodesData:
                     else:
                         external_config_filename = None
 
-                    if isinstance(export_cmd, str):
-                        export_call = [export_cmd]
-                    else:
-                        export_call = export_cmd
+                    export_call = copy.deepcopy(export_cmd)
+
+                    # add switch specific parameters
+                    export_call.extend(export_args)
 
                     export_call += ['-rec', file_path,
                                     '-outputdirectory', out_date_dir,
@@ -1403,17 +1419,16 @@ class ExtractRawTrodesData:
                     if external_config_filename is not None:
                         export_call += ['-reconfig', external_config_filename]
 
-                    export_call.extend(export_args)
-
                     # if pool slots are full, wait for one subprocess to terminate
-                    just_terminated = self._wait_subprocess_pool(subprocess_pool=subprocess_pool,
-                                                                 wait_pool_size=parallel_instances - 1)
+                    just_terminated = self._wait_subprocess_pool(
+                        subprocess_pool=subprocess_pool,
+                        wait_pool_size=parallel_instances - 1)
                     terminated_processes.update(just_terminated)
 
-                    # create log file for each run of the export command
                     out_cmd_log_filename = os.path.join(
                         out_epoch_dir, out_base_filename + '.' +
-                        ''.join(export_cmd) + '.log')
+                        cmd_type + '.log')
+
                     out_cmd_log_file = open(out_cmd_log_filename, 'w')
                     # prepend the call command and argument to the log file
                     out_cmd_log_file.write(' '.join(export_call))
@@ -1425,11 +1440,12 @@ class ExtractRawTrodesData:
                                  out_base_date, file_parser.epochlist_str))
                     print('(ID: {}) Full command: {}'.format(
                         next_cmd_id, export_call))
-                    #subprocess_pool[next_cmd_id] = subprocess.Popen(export_call)
-                    subprocess_pool[next_cmd_id] = (subprocess.Popen(export_call,
-                                                                     stdout=out_cmd_log_file,
-                                                                     stderr=out_cmd_log_file),
-                                                    out_cmd_log_filename)
+
+                    subprocess_pool[next_cmd_id] = (
+                        subprocess.Popen(export_call,
+                                         stdout=out_cmd_log_file,
+                                         stderr=out_cmd_log_file),
+                        out_cmd_log_filename)
                     next_cmd_id += 1
 
             except TrodesDataFormatError as err:
@@ -1438,10 +1454,10 @@ class ExtractRawTrodesData:
                     raise
                 else:
                     # exception should be converted to a warning
-                    warnings.warn(repr(err) + ' (thrown from {}:{})'
-                                  .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
-                                          sys.exc_info()[2].tb_lineno),
-                                  TrodesDataFormatWarning)
+                    logger.warn(repr(err) + ' (thrown from {}:{})'
+                                .format(sys.exc_info()[2].tb_frame.f_code.co_filename,
+                                        sys.exc_info()[2].tb_lineno),
+                                TrodesDataFormatWarning)
 
         # wait for all commands to finish
         just_terminated = self._wait_subprocess_pool(
@@ -1450,8 +1466,8 @@ class ExtractRawTrodesData:
 
         for cmd_key, (extract_proc, cmd_log_file) in terminated_processes.items():
             if extract_proc.poll() != 0:
-                warnings.warn('Running export command ({}) failed with return code {}'.
-                              format(extract_proc.args, extract_proc.poll()), TrodesDataFormatWarning)
+                logger.warn('Running export command ({}) failed with return code {}'.
+                            format(extract_proc.args, extract_proc.poll()), TrodesDataFormatWarning)
 
     @staticmethod
     def _assemble_export_base_name(date, anim_name, epochlist, label, label_ext):
@@ -1497,3 +1513,17 @@ def get_trodes_version(rec_file_name):
                .partition('"')[0]
                .split('.'))
     return int(version[0]), int(version[1]), int(version[2])
+
+
+def get_trodes_version_from_path():
+    try:
+        result = str(subprocess.run(['exportmda', '-v'], capture_output=True)
+                     .stdout)
+    except FileNotFoundError:
+        result = str(subprocess.run(['trodesexport', '-v'], capture_output=True)
+                     .stdout)
+    version = (result
+               .split('\\n')[0]
+               .split(' ')[-1]
+               .split('.'))
+    return int(version[0]), int(version[1]), int(version[2])
